# Summary

[Introduction](./introduction.md)

# Preliminaries

- [Architecture](./architecture.md)
- [Source code, Building, and Installation](./install.md)
- [Glossary](./glossary.md)

# User and Administration Guide

- [System overview](./operation/index.md)
- [The System Bus: syndicate-server](./operation/system-bus.md)
  - [Configuration language](./operation/scripting.md)
  - [Services and service dependencies](./operation/service.md)
  - [Built-in services and service classes](./operation/builtin/index.md)
    - [Gatekeeper](./operation/builtin/gatekeeper.md)
    - [Logging](./operation/builtin/logging.md)
    - [TCP/IP, WebSocket and Unix-socket Transports](./operation/builtin/relay-listener.md)
    - [Configuration watcher](./operation/builtin/config-watcher.md)
    - [Daemons and external programs](./operation/builtin/daemon.md)
- [Configuration files and directories]()
  - [The boot layer]()
    - [Logging]()
    - ["Machine" dataspace]()
    - ["exec" of one-off tasks]()
  - [The core layer]()
  - [The services layer]()
    - [Networking core]()
    - [Wifi & Mobile Data]()
    - [Simple daemons]()
      - [docker]()
      - [ntpd]()
      - [sshd]()
    - [User settings]()
- [Defining services and service classes]()
- [Scheduling tasks]()
  - [Timer tolerances]()
  - [One-off tasks]()
  - [Repeating tasks]()
- [Managing user settings]()
- [Restarting services]()
- [Rebooting and powering off the machine]()
- [Suspending the machine]()
- [Standard tools]()
  - [preserves-tools]()
- [Standard libraries]()
  - [Python support libraries]()
  - [Shell-scripting libraries]()
- [Standard protocols and schema definitions]()
  - [Preserves schemas]()
    - [Preserves Schema metaschema]()
    - [Preserves Path schema]()
  - [Syndicated Actor Model schemas]()
    - ["Observe" assertions]()
    - [Patterns over assertions]()
    - [Gatekeeper and Sturdy-references]()
    - [Wire-protocol]()
    - [Service dependencies]()
    - [Tracing]()
    - [Transport addresses]()
  - [Synit schemas]()
    - [Audio control]()
    - [Telephony (call and SMS) support]()
    - [Modem support]()
      - [Hayes]()
      - [Samsung Galaxy S7]()
    - [MIME type support]()
    - [Network core status and configuration]()
    - [Sound effects]()
    - [Time stamps]()
    - [User interface definitions and interaction]()
    - [User settings]()

# Programming Guide and Reference

- [Overview](./guide/index.md)
- [Preserves](./guide/preserves.md)
- [Working with schemas](./guide/working-with-schemas.md)
- [Language-neutral protocols]()
- [Rust]()
- [Python]()
- [Smalltalk]()
- [Bash (Shell)]()
- [Capturing and rendering interaction traces](./guide/tracing.md)

# Specifications and Theory

- [Overview](./theory/index.md)
- [Syndicated Actor Model](./syndicated-actor-model.md)
- [Protocol specification](./protocol.md)
- [System layer analysis]()
